@@ -42,6 +42,7 @@ class Distribution(pd.Series):
         that Series() and Series([]) yield different results.
         See: https://github.com/pandas-dev/pandas/issues/16737
         """
+        underride(kwargs, name='')
         if args or ('index' in kwargs):
             super().__init__(*args, **kwargs)
         else:
@@ -764,7 +765,6 @@ class Pmf(Distribution):
         series = pd.Series(seq).value_counts(normalize=normalize,
                                              sort=False,
                                              dropna=dropna)
-
         # make the result a Pmf
         # (since we just made a fresh Series, there is no reason to copy it)
         options['copy'] = False
@@ -772,12 +772,26 @@ class Pmf(Distribution):
 
         # sort in place, if desired
         if sort:
-            pmf.sort_index(ascending=ascending,
-                           inplace=True,
-                           na_position=na_position)
+            pmf.sort(ascending=ascending, na_position=na_position)
+
+        """In the current implementation, `from_seq` sorts numerical
+           quantities whether you want to or not.  If keeping
+           the order of the elements is important, let me know and
+           I'll rethink the implementation
+        """
 
         return pmf
 
+    def sort(self, ascending=True, na_position='last'):
+        """Sort the quantities in place.
+
+        ascending: boolean, ascending order, default True
+        na_position: where to put NaN, default last
+        """
+        self.sort_index(ascending=ascending,
+                        inplace=True,
+                        na_position=na_position)
+
 
 class Cdf(Distribution):
     """Represents a Cumulative Distribution Function (CDF)."""
