@@ -54,6 +54,24 @@ class Test(unittest.TestCase):
         res = pmf(xs)
         self.assertListEqual(list(res), [0, 1, 2, 1, 0, 1, 0])
 
+        pmf = Pmf.from_seq(t)
+        self.assertEqual(pmf.name, '')
+
+        pmf = Pmf.from_seq(t, name='test')
+        self.assertEqual(pmf.name, 'test')
+
+
+    def testSort(self):
+        t = [5, 4, 3, 2, 1]
+        pmf1 = Pmf.from_seq(t)
+        self.assertListEqual(list(pmf1.qs), [1, 2, 3, 4, 5])
+
+        # This generates a warning
+        #pmf2 = Pmf.from_seq(t, sort=False)
+        #print(pmf2)
+        #self.assertListEqual(list(pmf2.qs), t)
+
+
     def testStats(self):
         pmf = Pmf.from_seq([1, 2, 3, 4, 5, 6])
         self.assertAlmostEqual(pmf.mean(), 3.5)
